# DiagnosisType

None

URI: DiagnosisType

## Permissible Values

| Value | Meaning | Description | Info |
| --- | --- | --- | --- |
| TODO | None | None | |


## Identifier and Mapping Information


